=============
Django Statsd
=============

.. image:: https://coveralls.io/repos/github/vikingco/django-statsd/badge.svg?branch=master
    :target: https://coveralls.io/github/vikingco/django-statsd?branch=master
.. image:: https://travis-ci.org/vikingco/django-statsd.svg?branch=master
    :target: https://travis-ci.org/vikingco/django-statsd

This is a friendly fork with support for Django>1.8,<2.1.

The original documentation is on `Read the Docs <https://django-statsd.readthedocs.org/>`_.

-------
License
-------

BSD and MPL

Portions of this are from commonware:

https://github.com/jsocol/commonware/blob/master/LICENSE
